==> octave-4.0.0_0.zip: octave-4.0.0/lib/gdcm-2.0/GDCMTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "gdcmCommon" for configuration "Release"
set_property(TARGET gdcmCommon APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmCommon PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmCommon.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmCommon.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmCommon )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmCommon "${_IMPORT_PREFIX}/lib/libgdcmCommon.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmCommon.dll" )

# Import target "gdcmDICT" for configuration "Release"
set_property(TARGET gdcmDICT APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmDICT PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmDICT.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "gdcmDSED;gdcmIOD"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmDICT.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmDICT )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmDICT "${_IMPORT_PREFIX}/lib/libgdcmDICT.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmDICT.dll" )

# Import target "gdcmDSED" for configuration "Release"
set_property(TARGET gdcmDSED APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmDSED PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmDSED.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "gdcmzlib"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "gdcmCommon"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmDSED.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmDSED )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmDSED "${_IMPORT_PREFIX}/lib/libgdcmDSED.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmDSED.dll" )

# Import target "gdcmIOD" for configuration "Release"
set_property(TARGET gdcmIOD APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmIOD PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmIOD.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "gdcmexpat"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "gdcmDSED;gdcmCommon"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmIOD.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmIOD )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmIOD "${_IMPORT_PREFIX}/lib/libgdcmIOD.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmIOD.dll" )

# Import target "gdcmMSFF" for configuration "Release"
set_property(TARGET gdcmMSFF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmMSFF PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmMSFF.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "gdcmjpeg8;gdcmjpeg12;gdcmjpeg16;gdcmopenjpeg;gdcmcharls"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "gdcmDSED;gdcmDICT;gdcmIOD"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmMSFF.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmMSFF )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmMSFF "${_IMPORT_PREFIX}/lib/libgdcmMSFF.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmMSFF.dll" )

# Import target "gdcmjpeg8" for configuration "Release"
set_property(TARGET gdcmjpeg8 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmjpeg8 PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmjpeg8.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmjpeg8.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmjpeg8 )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmjpeg8 "${_IMPORT_PREFIX}/lib/libgdcmjpeg8.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmjpeg8.dll" )

# Import target "gdcmjpeg12" for configuration "Release"
set_property(TARGET gdcmjpeg12 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmjpeg12 PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmjpeg12.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmjpeg12.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmjpeg12 )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmjpeg12 "${_IMPORT_PREFIX}/lib/libgdcmjpeg12.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmjpeg12.dll" )

# Import target "gdcmjpeg16" for configuration "Release"
set_property(TARGET gdcmjpeg16 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmjpeg16 PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmjpeg16.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmjpeg16.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmjpeg16 )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmjpeg16 "${_IMPORT_PREFIX}/lib/libgdcmjpeg16.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmjpeg16.dll" )

# Import target "gdcmexpat" for configuration "Release"
set_property(TARGET gdcmexpat APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmexpat PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmexpat.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmexpat.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmexpat )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmexpat "${_IMPORT_PREFIX}/lib/libgdcmexpat.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmexpat.dll" )

# Import target "gdcmopenjpeg" for configuration "Release"
set_property(TARGET gdcmopenjpeg APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmopenjpeg PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmopenjpeg.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmopenjpeg.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmopenjpeg )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmopenjpeg "${_IMPORT_PREFIX}/lib/libgdcmopenjpeg.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmopenjpeg.dll" )

# Import target "gdcmcharls" for configuration "Release"
set_property(TARGET gdcmcharls APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmcharls PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmcharls.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmcharls.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmcharls )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmcharls "${_IMPORT_PREFIX}/lib/libgdcmcharls.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmcharls.dll" )

# Import target "gdcmzlib" for configuration "Release"
set_property(TARGET gdcmzlib APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmzlib PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmzlib.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmzlib.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmzlib )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmzlib "${_IMPORT_PREFIX}/lib/libgdcmzlib.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmzlib.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> octave-4.0.3.zip: octave-4.0.3/lib/gdcm-2.4/GDCMTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "gdcmCommon" for configuration "Release"
set_property(TARGET gdcmCommon APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmCommon PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmCommon.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmCommon.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmCommon )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmCommon "${_IMPORT_PREFIX}/lib/libgdcmCommon.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmCommon.dll" )

# Import target "gdcmDICT" for configuration "Release"
set_property(TARGET gdcmDICT APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmDICT PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmDICT.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "gdcmDSED;gdcmIOD"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmDICT.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmDICT )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmDICT "${_IMPORT_PREFIX}/lib/libgdcmDICT.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmDICT.dll" )

# Import target "gdcmDSED" for configuration "Release"
set_property(TARGET gdcmDSED APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmDSED PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmDSED.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "gdcmzlib"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "gdcmCommon"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmDSED.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmDSED )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmDSED "${_IMPORT_PREFIX}/lib/libgdcmDSED.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmDSED.dll" )

# Import target "gdcmIOD" for configuration "Release"
set_property(TARGET gdcmIOD APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmIOD PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmIOD.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "gdcmexpat"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "gdcmDSED;gdcmCommon"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmIOD.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmIOD )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmIOD "${_IMPORT_PREFIX}/lib/libgdcmIOD.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmIOD.dll" )

# Import target "gdcmMSFF" for configuration "Release"
set_property(TARGET gdcmMSFF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmMSFF PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmMSFF.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "gdcmjpeg8;gdcmjpeg12;gdcmjpeg16;gdcmopenjpeg;gdcmcharls"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "gdcmDSED;gdcmDICT;gdcmIOD"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmMSFF.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmMSFF )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmMSFF "${_IMPORT_PREFIX}/lib/libgdcmMSFF.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmMSFF.dll" )

# Import target "gdcmMEXD" for configuration "Release"
set_property(TARGET gdcmMEXD APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmMEXD PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmMEXD.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "gdcmMSFF;gdcmDICT;gdcmDSED;gdcmIOD;socketxx"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmMEXD.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmMEXD )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmMEXD "${_IMPORT_PREFIX}/lib/libgdcmMEXD.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmMEXD.dll" )

# Import target "gdcmjpeg8" for configuration "Release"
set_property(TARGET gdcmjpeg8 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmjpeg8 PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmjpeg8.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmjpeg8.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmjpeg8 )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmjpeg8 "${_IMPORT_PREFIX}/lib/libgdcmjpeg8.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmjpeg8.dll" )

# Import target "gdcmjpeg12" for configuration "Release"
set_property(TARGET gdcmjpeg12 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmjpeg12 PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmjpeg12.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmjpeg12.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmjpeg12 )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmjpeg12 "${_IMPORT_PREFIX}/lib/libgdcmjpeg12.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmjpeg12.dll" )

# Import target "gdcmjpeg16" for configuration "Release"
set_property(TARGET gdcmjpeg16 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmjpeg16 PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmjpeg16.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmjpeg16.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmjpeg16 )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmjpeg16 "${_IMPORT_PREFIX}/lib/libgdcmjpeg16.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmjpeg16.dll" )

# Import target "gdcmexpat" for configuration "Release"
set_property(TARGET gdcmexpat APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmexpat PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmexpat.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmexpat.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmexpat )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmexpat "${_IMPORT_PREFIX}/lib/libgdcmexpat.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmexpat.dll" )

# Import target "gdcmopenjpeg" for configuration "Release"
set_property(TARGET gdcmopenjpeg APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmopenjpeg PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmopenjpeg.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmopenjpeg.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmopenjpeg )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmopenjpeg "${_IMPORT_PREFIX}/lib/libgdcmopenjpeg.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmopenjpeg.dll" )

# Import target "gdcmcharls" for configuration "Release"
set_property(TARGET gdcmcharls APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmcharls PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmcharls.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmcharls.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmcharls )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmcharls "${_IMPORT_PREFIX}/lib/libgdcmcharls.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmcharls.dll" )

# Import target "gdcmzlib" for configuration "Release"
set_property(TARGET gdcmzlib APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmzlib PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmzlib.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmzlib.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmzlib )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmzlib "${_IMPORT_PREFIX}/lib/libgdcmzlib.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmzlib.dll" )

# Import target "gdcmgetopt" for configuration "Release"
set_property(TARGET gdcmgetopt APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmgetopt PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmgetopt.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libgdcmgetopt.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmgetopt )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmgetopt "${_IMPORT_PREFIX}/lib/libgdcmgetopt.dll.a" "${_IMPORT_PREFIX}/bin/libgdcmgetopt.dll" )

# Import target "socketxx" for configuration "Release"
set_property(TARGET socketxx APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(socketxx PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libsocketxx.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libsocketxx.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS socketxx )
list(APPEND _IMPORT_CHECK_FILES_FOR_socketxx "${_IMPORT_PREFIX}/lib/libsocketxx.dll.a" "${_IMPORT_PREFIX}/bin/libsocketxx.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
